@@ -19,10 +19,10 @@ formatPT <- function(x, lab = FALSE, labval = "p", noblanks = FALSE,
                       ifelse(x == 0,
                              paste(labval, "= 0"),
                       ifelse(x < 1 / 10^digits,
-                             paste(labval, " < 0", outdec,
-                                   paste(rep("0",
+                             paste0(labval, " < 0", outdec,
+                                    paste(rep("0",
                                              n.zeros), collapse = ""),
-                                   "1", sep = ""),
+                                    "1"),
                              paste(paste(labval, "="),
                                    formatC(round(x, digits),
                                            decimal.mark = outdec,
@@ -69,9 +69,9 @@ formatPT <- function(x, lab = FALSE, labval = "p", noblanks = FALSE,
                       ifelse(x == 0,
                              0,
                       ifelse(x < 1 / 10^digits,
-                             paste("< 0", outdec,
-                                   paste(rep("0", n.zeros), collapse = ""),
-                                   "1", sep = ""),
+                             paste0("< 0", outdec,
+                                    paste(rep("0", n.zeros), collapse = ""),
+                                    "1"),
                              formatC(round(x, digits),
                                      decimal.mark = outdec,
                                      big.mark = big.mark,
