@@ -1638,20 +1638,28 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
       data$.mean.e <- mean.e
       data$.sd.c <- sd.c
       data$.mean.c <- mean.c
-      data$.approx.sd.e <- approx.sd.e
-      data$.approx.sd.c <- approx.sd.c
-      data$.approx.mean.e <- approx.mean.e
-      data$.approx.mean.c <- approx.mean.c
+      if (!missing.approx.sd.e)
+        data$.approx.sd.e <- approx.sd.e
+      if (!missing.approx.sd.c)
+        data$.approx.sd.c <- approx.sd.c
+      if (!missing.approx.mean.e)
+        data$.approx.mean.e <- approx.mean.e
+      if (!missing.approx.mean.c)
+        data$.approx.mean.c <- approx.mean.c
     }
     else {
       data$.sd.e[data$.subset] <- sd.e
       data$.mean.e[data$.subset] <- mean.e
       data$.sd.c[data$.subset] <- sd.c
       data$.mean.c[data$.subset] <- mean.c
-      data$.approx.sd.e[data$.subset] <- approx.sd.e
-      data$.approx.sd.c[data$.subset] <- approx.sd.c
-      data$.approx.mean.e[data$.subset] <- approx.mean.e
-      data$.approx.mean.c[data$.subset] <- approx.mean.c
+      if (!missing.approx.sd.e)
+        data$.approx.sd.e[data$.subset] <- approx.sd.e
+      if (!missing.approx.sd.c)
+        data$.approx.sd.c[data$.subset] <- approx.sd.c
+      if (!missing.approx.mean.e)
+        data$.approx.mean.e[data$.subset] <- approx.mean.e
+      if (!missing.approx.mean.c)
+        data$.approx.mean.c[data$.subset] <- approx.mean.c
     }
   }
   
@@ -1738,7 +1746,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
       ##
       TE <- smd
       seTE <- ifelse(npn.n, NA,
-                     sqrt(N / (n.e * n.c) + TE^2 / (2 * n.g - 1)))
+                     sqrt(N / (n.e * n.c) + TE^2 / (2 * (n.g - 1))))
     }
     ##
     seTE[is.na(TE)] <- NA
