@@ -263,13 +263,13 @@
 #' In rare settings with very homogeneous treatment estimates, the
 #' Hartung-Knapp variance estimate can be arbitrarily small resulting
 #' in a very narrow confidence interval (Knapp and Hartung, 2003;
-#' Wiksten et al., 2016). In such cases, an
-#' \emph{ad hoc} variance correction has been proposed by utilising
-#' the variance estimate from the classic random effects model with
-#' the HK method (Knapp and Hartung, 2003; IQWiQ, 2020). An
-#' alternative approach is to use the wider confidence interval of
-#' classic fixed or random effects meta-analysis and the HK method
-#' (Wiksten et al., 2016; Jackson et al., 2017).
+#' Wiksten et al., 2016). In such cases, an \emph{ad hoc} variance
+#' correction has been proposed by utilising the variance estimate
+#' from the classic random effects model with the HK method (Knapp and
+#' Hartung, 2003; IQWiQ, 2020). An alternative approach is to use the
+#' wider confidence interval of classic fixed or random effects
+#' meta-analysis and the HK method (Wiksten et al., 2016; Jackson et
+#' al., 2017).
 #'
 #' Argument \code{adhoc.hakn} can be used to choose the \emph{ad hoc}
 #' method:
@@ -290,6 +290,11 @@
 #'  \tab and HK meta-analysis \cr
 #'  \tab (Hybrid method 2 in Jackson et al., 2017)
 #' }
+#' 
+#' For GLMMs, a method similar to Knapp and Hartung (2003) is
+#' implemented, see description of argument \code{tdist} in
+#' \code{\link[metafor]{rma.glmm}}, and the \emph{ad hoc} variance
+#' correction is not available.
 #' }
 #' 
 #' \subsection{Prediction interval}{
@@ -301,10 +306,6 @@
 #' implements equation (12) of Higgins et al., (2009) which proposed a
 #' \emph{t} distribution with \emph{K-2} degrees of freedom where
 #' \emph{K} corresponds to the number of studies in the meta-analysis.
-#' 
-#' For GLMMs, a method similar to Knapp and Hartung (2003) is
-#' implemented, see description of argument \code{tdist} in
-#' \code{\link[metafor]{rma.glmm}}.
 #' }
 #'
 #' \subsection{Subgroup analysis}{
@@ -700,6 +701,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   chklogical(overall.hetstat)
   ##
   chklogical(hakn)
+  missing.adhoc.hakn <- missing(adhoc.hakn)
   adhoc.hakn <- setchar(adhoc.hakn, .settings$adhoc4hakn)
   method.tau <- setchar(method.tau, .settings$meth4tau)
   if (is.null(method.tau.ci))
@@ -748,10 +750,22 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   chklogical(warn)
   ##
   if (is.glmm & sm != "IRR")
-    stop("Generalised linear mixed models only possible with argument 'sm = \"IRR\"'.")
+    stop("Generalised linear mixed models only possible with ",
+         "argument 'sm = \"IRR\"'.",
+         call. = FALSE)
   ##
   if (is.glmm & method.tau != "ML")
-    stop("Generalised linear mixed models only possible with argument 'method.tau = \"ML\"'.")
+    stop("Generalised linear mixed models only possible with ",
+         "argument 'method.tau = \"ML\"'.",
+         call. = FALSE)
+  ##
+  if (is.glmm & hakn & adhoc.hakn != "") {
+    if (!missing.adhoc.hakn)
+      warning("Ad hoc variance correction for Hartung-Knapp method ",
+              "not available for GLMMs.",
+              call. = FALSE)
+    adhoc.hakn <- ""
+  }
   
   
   ##
@@ -766,7 +780,8 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ##
   mf <- match.call()
   ##
-  ## Catch 'event.e', 'time.e', 'event.c', 'time.c', 'n.e', and 'n.c' from data:
+  ## Catch 'event.e', 'time.e', 'event.c', 'time.c', 'n.e', and 'n.c'
+  ## from data:
   ##
   event.e <- eval(mf[[match("event.e", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
@@ -787,8 +802,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ##
   n.e <- eval(mf[[match("n.e", names(mf))]],
               data, enclos = sys.frame(sys.parent()))
+  null.n.e <- is.null(n.e)
+  ##
   n.c <- eval(mf[[match("n.c", names(mf))]],
               data, enclos = sys.frame(sys.parent()))
+  null.n.c <- is.null(n.c)
   ##
   ## Catch 'incr' from data:
   ##
@@ -832,7 +850,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   if (by)
     chklength(byvar, k.All, fun)
   ##
-  if (!is.null(n.e))
+  if (!null.n.e)
     chklength(n.e, k.All, fun)
   if (!is.null(n.c))
     chklength(n.c, k.All, fun)
@@ -853,11 +871,13 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     }
   }
   if (!by & tau.common) {
-    warning("Value for argument 'tau.common' set to FALSE as argument 'byvar' is missing.")
+    warning("Value for argument 'tau.common' set to FALSE as ",
+            "argument 'byvar' is missing.")
     tau.common <- FALSE
   }
   if (by & !tau.common & !is.null(tau.preset)) {
-    warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
+    warning("Argument 'tau.common' set to TRUE as ",
+            "argument tau.preset is not NULL.")
     tau.common <- TRUE
   }
   
@@ -919,9 +939,9 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     if (!missing.exclude)
       data$.exclude <- exclude
     ##
-    if (!is.null(n.e))
+    if (!null.n.e)
       data$.n.e <- n.e
-    if (!is.null(n.e))
+    if (!null.n.e)
       data$.n.c <- n.c
   }  
   
@@ -946,7 +966,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     if (by)
       byvar <- byvar[subset]
     ##
-    if (!is.null(n.e))
+    if (!null.n.e)
       n.e <- n.e[subset]
     if (!is.null(n.c))
       n.c <- n.c[subset]
@@ -1451,6 +1471,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     ##
     res$event.w <- NULL
     res$n.w <- NULL
+    ##
+    if (null.n.e)
+      res$n.e.w <- NULL
+    if (null.n.c)
+      res$n.c.w <- NULL
   }
   ##
   class(res) <- c(fun, "meta")
